"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _react = _interopRequireWildcard(require("react"));

var _translateMaker = _interopRequireDefault(require("translate-maker"));

var _enzyme = require("enzyme");

var _index = require("./index");

describe('Translate', () => {
  it('should be able to create simple instance',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          test: 'Test response'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "test"
    })));
    expect(wrapper.text()).toBe('Test response');
  }));
  it('should be able to create simple instance with default value', () => {
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK"
    }, _react.default.createElement(_index.Translate, {
      path: "test",
      defaultValue: "Default value"
    })));
    expect(wrapper.text()).toBe('Default value');
  });
  it('should be able to create simple instance with default value as children', () => {
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK"
    }, _react.default.createElement(_index.Translate, {
      path: "test"
    }, "Default value")));
    expect(wrapper.text()).toBe('Default value');
  });
  it('should be able to create element h1',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          test: 'Test response'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement("h1", null, _react.default.createElement(_index.Translate, {
      path: "test",
      defaultValue: "Default value"
    }))));
    expect(wrapper.html()).toBe('<h1>Test response</h1>');
  }));
  it('should be able to use variable inside translation',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          hello: 'Hello {$name}'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "hello",
      name: "Zlatko"
    })));
    expect(wrapper.text()).toBe('Hello Zlatko');
  }));
  it('should be able to use plurals inside translation',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          followers: `{$name} has {$followers, plural,
            =0 {no followers}
            =1 {# follower}
               {# followers}
          }`
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "followers",
      name: "Zlatko",
      followers: 0
    })));
    expect(wrapper.text()).toBe('Zlatko has no followers');
  }));
  it('should be able to use params instead of props',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          hello: 'Hello {$name}'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const user = {
      name: 'Zlatko'
    };
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "hello",
      params: user
    })));
    expect(wrapper.text()).toBe('Hello Zlatko');
  }));
  it('should be able to use html content',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          hello: 'Welcome back <b>{$name}</b>. How is it going?'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "hello",
      name: "Zlatko",
      html: true
    })));
    expect(wrapper.html()).toBe('<span>Welcome back <b>Zlatko</b>. How is it going?</span>');
  }));
  it('should be able to use filters',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          hello: 'Hello {$name | star}'
        }
      },
      filters: {
        star: value => '*** ' + value + ' ***'
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "hello",
      name: "Zlatko"
    })));
    expect(wrapper.text()).toBe('Hello *** Zlatko ***');
  }));
  it('should be able to use namespace',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          namespace: {
            test: 'Test response'
          }
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Namespace, {
      path: "namespace"
    }, _react.default.createElement(_index.Translate, {
      path: "test"
    }))));
    expect(wrapper.text()).toBe('Test response');
  }));
  it('should be able to change namespace',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          namespace1: {
            test: 'Test response'
          },
          namespace2: {
            test: 'Test response2'
          }
        }
      }
    });
    yield translate.setLocale('sk_SK');

    const Main = ({
      namespace
    }) => _react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Namespace, {
      path: namespace
    }, _react.default.createElement(_index.Translate, {
      path: "test"
    })));

    const wrapper = (0, _enzyme.mount)(_react.default.createElement(Main, {
      namespace: "namespace1"
    }));
    expect(wrapper.text()).toBe('Test response');
    wrapper.setProps({
      namespace: 'namespace2'
    });
    expect(wrapper.text()).toBe('Test response2');
  }));
  it('should be able to use namespace inside namespace',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          namespace1: {
            namespace2: {
              test: 'Test response'
            }
          }
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Namespace, {
      path: "namespace1"
    }, _react.default.createElement(_index.Namespace, {
      path: "namespace2",
      compose: true
    }, _react.default.createElement(_index.Translate, {
      path: "test"
    })))));
    expect(wrapper.text()).toBe('Test response');
  }));
  it('should be able to use namespace inside namespace with replace',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          namespace: {
            test: 'Test response'
          }
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Namespace, {
      path: "namespace1"
    }, _react.default.createElement(_index.Namespace, {
      path: "namespace"
    }, _react.default.createElement(_index.Translate, {
      path: "test"
    })))));
    expect(wrapper.text()).toBe('Test response');
  }));
  it('should be able to use LocaleSwitch as uncontrolled component',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const data = {
      sk_SK: {
        test: 'Testovacia odpoved'
      },
      en_US: {
        test: 'Test response'
      }
    };
    const translate = new _translateMaker.default({
      data
    });
    yield translate.setLocale('sk_SK');
    let changeLocale;
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      data: data,
      locale: "sk_SK",
      translate: translate,
      controlled: false
    }, _react.default.createElement("div", null, _react.default.createElement("span", null, _react.default.createElement(_index.Translate, {
      path: "test"
    })), _react.default.createElement(_index.LocaleSwitch, {
      onError: err => {
        throw err;
      }
    }, props => {
      changeLocale = props.changeLocale;
      return null;
    }))));
    expect(wrapper.text()).toBe('Testovacia odpoved');
    yield changeLocale('en_US');
    expect(wrapper.text()).toBe('Test response');
  }));
  it('should be able to use LocaleSwitch as uncontrolled component',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          test: 'Testovacia odpoved'
        },
        en_US: {
          test: 'Test response'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    return new Promise((resolve, reject) => {
      let wrapper;

      function handleLocaleChange(newLocale) {
        expect(newLocale).toBe('en_US');
        expect(wrapper.find('span').html()).toBe('<span>Test response</span>');
        resolve();
      }

      let onChange;

      const Main = () => _react.default.createElement(_index.LocaleProvider, {
        translate: translate,
        controlled: false
      }, _react.default.createElement("div", null, _react.default.createElement("span", null, _react.default.createElement(_index.Translate, {
        path: "test"
      })), _react.default.createElement(_index.LocaleSwitch, {
        onChange: handleLocaleChange,
        onError: reject
      }, ({
        changeLocale
      }) => {
        onChange = changeLocale;
        return null;
      })));

      wrapper = (0, _enzyme.mount)(_react.default.createElement(Main, null));
      expect(wrapper.find('span').html()).toBe('<span>Testovacia odpoved</span>');
      onChange('en_US'); // wrapper.find('select').simulate('change', {target: { value : 'en_US'}});
    });
  }));
  it('should be able to use t decorator',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          test: 'Testovacia odpoved'
        }
      }
    });
    yield translate.setLocale('sk_SK');

    class Test extends _react.Component {
      render() {
        return _react.default.createElement("div", null, this.props.translate('test'));
      }

    }

    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.ProvideTranslate, null, t => _react.default.createElement(Test, {
      translate: t
    }))));
    expect(wrapper.html()).toBe('<div>Testovacia odpoved</div>');
  }));
  it('should be able to other components as props',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          test: 'Testovacia odpoved {$link}'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "test",
      link: _react.default.createElement("a", null, "Asdf"),
      html: true
    })));
    expect(wrapper.html()).toBe('<span>Testovacia odpoved <a>Asdf</a></span>');
  }));
  it('should be able to other components as props with Translate',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          test: 'Testovacia odpoved {$link}',
          inner: '123'
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      translate: translate
    }, _react.default.createElement(_index.Translate, {
      path: "test",
      link: _react.default.createElement("a", null, "Asdf ", _react.default.createElement(_index.Translate, {
        path: "inner"
      })),
      html: true
    })));
    expect(wrapper.html()).toBe('<span>Testovacia odpoved <a>Asdf 123</a></span>');
  }));
  it('should be able to use namespace',
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(function* () {
    const translate = new _translateMaker.default({
      data: {
        sk_SK: {
          namespace: {
            test: 'Testovacia odpoved'
          }
        }
      }
    });
    yield translate.setLocale('sk_SK');
    const wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.LocaleProvider, {
      locale: "sk_SK",
      namespace: "namespace",
      translate: translate
    }, _react.default.createElement(_index.Namespace, {
      path: "namespace"
    }, _react.default.createElement(_index.Translate, {
      path: "test",
      html: true
    }))));
    expect(wrapper.html()).toBe('<span>Testovacia odpoved</span>');
  }));
});
//# sourceMappingURL=Translate.test.js.map